@@ -38,23 +38,19 @@ be ignored; instead, users should use the
 Functions
 =========
 
-.. autofunction:: init_database
+.. autofunction:: init_databases
 
 .. autofunction:: country_code_by_addr
 
-.. autofunction:: country_code_by_addr_v6
-
 .. autofunction:: city_by_addr
 
-.. autofunction:: city_by_addr_v6
-
 .. autofunction:: region_by_addr
 
-.. autofunction:: region_by_addr_v6
-
 .. autofunction:: coords_by_addr
 
-.. autofunction:: coords_by_addr_v6
+.. autofunction:: isp_by_addr
+
+.. autofunction:: org_by_addr
 
 
 Examples
@@ -68,12 +64,12 @@ from __future__ import (
     print_function,
     division,
     )
+str = type('')
 
 try:
     import ipaddress
-except ImportError: # pragma: no cover
-    # XXX Support old versions of ipaddress package
-    import ipaddr as ipaddress # pragma: no cover
+except ImportError:
+    import ipaddr as ipaddress
 from collections import namedtuple
 
 import pygeoip
@@ -176,20 +172,24 @@ def country_code_by_addr(address):
     If the geographical database for the address type has not been initialized,
     the function raises a ValueError.
 
-    :param str address: The address to lookup the country for
+    :param address: The address to lookup the country for
     :returns str: The country code associated with the address
     """
     # pygeoip returns '' instead of None in case a match isn't found. For
     # consistency with the GeoIP API, we convert this to None
     try:
         if isinstance(address, ipaddress.IPv4Address):
-            return _GEOIP_IPV4_GEO.country_code_by_addr(address.compressed).decode(_MAXMIND_ENCODING)
+            result = _GEOIP_IPV4_GEO.country_code_by_addr(address.compressed)
         else:
-            return _GEOIP_IPV6_GEO.country_code_by_addr(address.compressed).decode(_MAXMIND_ENCODING)
+            result = _GEOIP_IPV6_GEO.country_code_by_addr(address.compressed)
     except AttributeError:
         raise ValueError(
             'Uninitialized geo database while looking up country '
             'for address %s' % address)
+    else:
+        if isinstance(result, str):
+            return result
+        return result.decode(_MAXMIND_ENCODING)
 
 def region_by_addr(address):
     """
@@ -207,7 +207,7 @@ def region_by_addr(address):
     If the geographical database for the address type has not been initialized,
     the function raises a ValueError.
 
-    :param str address: The address to lookup the region for
+    :param address: The address to lookup the region for
     :returns str: The region associated with the address, or None
     """
     # This is safe as pygeoip returns a dictionary with blank values in the
@@ -222,7 +222,10 @@ def region_by_addr(address):
             'Uninitialized geo database while looking up country '
             'for address %s' % address)
     if rec and 'region_name' in rec:
-        return rec['region_name'].decode(_MAXMIND_ENCODING)
+        result = rec['region_name']
+        if isinstance(result, str):
+            return result
+        return result.decode(_MAXMIND_ENCODING)
 
 def city_by_addr(address):
     """
@@ -238,7 +241,7 @@ def city_by_addr(address):
     If the geographical database for the address type has not been initialized,
     the function raises a ValueError.
 
-    :param str address: The address to lookup the city for
+    :param address: The address to lookup the city for
     :returns str: The city associated with the address, or None
     """
     try:
@@ -251,7 +254,10 @@ def city_by_addr(address):
             'Uninitialized geo database while looking up country '
             'for address %s' % address)
     if rec and 'city' in rec:
-        return rec['city'].decode(_MAXMIND_ENCODING)
+        result = rec['city']
+        if isinstance(result, str):
+            return result
+        return result.decode(_MAXMIND_ENCODING)
 
 def coords_by_addr(address):
     """
@@ -269,7 +275,7 @@ def coords_by_addr(address):
     If the geographical database for the address type has not been initialized,
     the function raises a ValueError.
 
-    :param str address: The address to locate
+    :param address: The address to locate
     :returns str: The coordinates associated with the address, or None
     """
     try:
@@ -294,18 +300,22 @@ def isp_by_addr(address):
     If the ISP database for the address type has not been initialized, the
     function raises a ValueError.
 
-    :param str address: The address to lookup the ISP for
+    :param address: The address to lookup the ISP for
     :returns str: The ISP associated with the address, or None
     """
     try:
         if isinstance(address, ipaddress.IPv4Address):
-            return _GEOIP_IPV4_ISP.org_by_addr(address.compressed).decode(_MAXMIND_ENCODING)
+            result = _GEOIP_IPV4_ISP.org_by_addr(address.compressed)
         else:
-            return _GEOIP_IPV6_ISP.org_by_addr(address.compressed).decode(_MAXMIND_ENCODING)
+            result = _GEOIP_IPV6_ISP.org_by_addr(address.compressed)
     except AttributeError:
         raise ValueError(
             'Uninitialized ISP database while looking up ISP '
             'for address %s' % address)
+    else:
+        if isinstance(result, str):
+            return result
+        return result.decode(_MAXMIND_ENCODING)
 
 def org_by_addr(address):
     """
@@ -317,11 +327,15 @@ def org_by_addr(address):
     """
     try:
         if isinstance(address, ipaddress.IPv4Address):
-            return _GEOIP_IPV4_ORG.org_by_addr(address.compressed).decode(_MAXMIND_ENCODING)
+            result = _GEOIP_IPV4_ORG.org_by_addr(address.compressed)
         else:
-            return _GEOIP_IPV6_ORG.org_by_addr(address.compressed).decode(_MAXMIND_ENCODING)
+            result = _GEOIP_IPV6_ORG.org_by_addr(address.compressed)
     except AttributeError:
         raise ValueError(
             'Uninitialized organisation database while looking up org '
             'for address %s' % address)
+    else:
+        if isinstance(result, str):
+            return result
+        return result.decode(_MAXMIND_ENCODING)
 
