@@ -98,6 +98,8 @@ from __future__ import (
     print_function,
     division,
     )
+str = type('')
+
 
 import io
 import sys
@@ -105,15 +107,6 @@ import time
 import logging
 
 
-# Make Py2 str same as Py3
-str = type('')
-
-
-__all__ = [
-    'ProgressMeter',
-    ]
-
-
 class ProgressStyle(object):
     def __init__(self, meter):
         """
@@ -298,4 +291,3 @@ class ProgressMeter(object):
             self._render()
             self.stream.write('\n')
 
-
