@@ -121,27 +121,22 @@ from __future__ import (
     print_function,
     division,
     )
+str = type('')
+
 
 import warnings
 import logging
-import ipaddress
+try:
+    import ipaddress
+except ImportError:
+    import ipaddr as ipaddress
 import sqlite3
 from datetime import date, time, datetime
 
 from lars import datatypes
 
 
-# Make Py2 str same as Py3
-str = type('')
-
-
-__all__ = [
-    'SQLTarget',
-    'SQLError',
-    ]
-
-
-class SQLError(StandardError):
+class SQLError(Exception):
     """
     Base class for all fatal errors generated by classes in the sql module.
 
